'use strict';

function TrackForm(props) {
  if (props.show) {
    return null
  }
  return (
    <div>
      <h1 className="text-2xl font-semibold text-gray-600 pb-5">Track Order</h1>
      <form action="">
        <div className="flex flex-col space-y-1">
          <label htmlFor="username" className="text-sm font-bold text-gray-500">Tracking Number</label>
          <div className="relative">
            <input type="text"
              className="block appearance-none tracking-wide w-full bg-gray-100 border border-gray-100 text-gray-500 py-3 px-4 pr-8 rounded" placeholder="Enter tracking number" />
          </div>
        </div>
        {!this.state.show && <div className="text-center mt-5">
          <button onClick={this.onSubmit}
            disabled={this.state.isLoading}
            className="inline-block bg-green-700 text-green-100 font-medium uppercase py-3 shadow px-16 rounded-md">{this.state.isLoading ? "Tracking..." : "Start Tracking"}</button>
        </div>}
      </form>
    </div>
  )
}


// Datetime formating 
function DateFormat(props) {
  const date_time = moment(props.date).format('MMMM Do YYYY, h:mm:ss a')
  return (
    <p className="leading-tight text-xs text-justify text-gray-500">
      Updated: {date_time}
    </p>
  )
}

function TrackOrderResult(props) {
  const track_number = props.track_number
  const [track_order_refresh, setTracklisting] = React.useState([])
  let track_order_list = props.list.logs
  const [isLoading, setIsloading] = React.useState(false)
  const user_data = props.list
  let refreshItems = () => {
    setIsloading(true);
    axios.get(`https://dev.ideliver.co.ls/api/packages/${track_number}`)
    // axios.get(`http://localhost:8000/api/packages/${track_number}`)
      .then(list => {
        setTracklisting(list.data.logs)
        setIsloading()
      });

  };
  if (!props.show) {
    return null
  }
  if (track_order_refresh.length !== 0) {
    track_order_list = track_order_refresh
  }
  return (
    <div>
      <div className="">
        <div className="text-center">

          <div>
            <h1 className="text-3xl text-gray-600 font-bold">{user_data.package_type}</h1>
            <p className="text-sm text-gray-600">Tracking Number: {user_data.waybill_number}</p>
            <p></p>
          </div>

        </div>
        <div
          className="flex flex-col md:grid grid-cols-9 mx-auto p-2 text-blue-50"
        >
          {/* <!-- Right --> */}
          {track_order_list.slice(0, 1).map((items, index) =>

            <div key={index} className="flex md:contents">
              <div className="col-start-5 col-end-6 mr-10 md:mx-auto relative">
                <div className="h-full w-6 flex items-center justify-center">
                  <div className="h-full w-1 bg-yellow-200 pointer-events-none"></div>
                </div>
                <div className="absolute top-1/2">
                  <span className="animate-ping absolute inline-flex w-6 h-6 rounded-full bg-yellow-600 opacity-75">
                  </span>
                  <span className="absolute top-1/2 inline-flex rounded-full  h-6 w-6 bg-yellow-500">
                  </span>
                </div>

              </div>
              <div
                className="bg-yellow-50 col-start-6 col-end-10 p-4 rounded-md my-4 mr-auto "
              >

                <h3 className="font-semibold text-sm mb-1 text-gray-500">Your Package</h3>
                <p className="leading-tight text-xs text-justify text-gray-500">
                  Status: (<span className="text-green-500 animate-pulse capitalize"> {items.event}</span> )
              </p>
                <DateFormat date={items.created} />
                <p className="leading-tight text-xs my-1 text-justify text-gray-500">
                  Location: {items.facility.city}, {items.facility.country}
                </p>
              </div>
            </div>
          )}
          {/* <!-- left --> */}
          {track_order_list.slice(1, 10).map((items, index) =>
            <div key={index} className="flex flex-row-reverse md:contents">
              <div
                className="bg-gray-50 col-start-1 col-end-5 p-4  rounded-xl my-4 ml-auto shadow-sm"
              >
                <h3 className="font-medium  text-xs mb-1 text-gray-600 tracking-tighter">{items.facility.city}, {items.facility.country}</h3>
                <p className="leading-tight text-xs text-justify text-gray-500">
                  Status: (<span className="text-green-500 animate-pulse capitalize"> {items.event}</span> )
              </p>
                <DateFormat date={items.created} />
                <p className="leading-tight text-gray-500 text-xs text-justify">
                  Facility: <span className="text-yellow-500">{items.facility.name}</span>
                </p>
              </div>
              <div className="col-start-5 col-end-6 md:mx-auto relative mr-10">
                <div className="h-full w-6 flex items-center justify-center">
                  <div className="h-full w-1 bg-gray-300 pointer-events-none"></div>
                </div>
                <div
                  className="w-6 h-6 absolute top-1/2 -mt-3 rounded-full bg-green-700 shadow"
                ></div>
              </div>
            </div>
          )}


        </div>
        <div className="text-center mt-5">
          <button onClick={refreshItems}
            className="inline-block bg-gray-500 text-gray-100 font-medium uppercase py-3 shadow px-10 rounded-md">{isLoading ? <svg class="animate-bounce w-6 h-6 text-amber-900" fill="none" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" viewBox="0 0 24 24" stroke="currentColor">
            <path d="M19 14l-7 7m0 0l-7-7m7 7V3"></path>
          </svg> : "Refresh"}
          </button>
        </div>
      </div>


    </div>
  )
}

class TrackOrder extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      error: '',
      isLoading: false,
      show: false,
      list: [],
      user: null,
      trackOrderNumber: '',
    };
    // this.handleToggleClick = this.handleToggleClick.bind(this);
  }


  onSubmit = event => {
    this.setState({ isLoading: true });
    // ${trackOrderNumber}
    axios.get(`https://dev.ideliver.co.ls/api/packages/${this.state.trackOrderNumber}`)
    // axios.get(`http://localhost:8000/api/packages/${this.state.trackOrderNumber}`)
      .then(list => {
        this.setState({
          isLoading: false,
          list: list.data,
          show: true
        });
        console.log(list.data)

      }).catch((errors) => {
        this.setState({ isLoading: false, error: 'Tracking numner not found' })
      });
    event.preventDefault();
  };

  render() {

    return (
      <div>
        <TrackOrderResult show={this.state.show} list={this.state.list} track_number={this.state.trackOrderNumber} />
        {!this.state.show && <div>
          <h1 className="text-2xl md:text-3xl font-semibold  text-gray-600">Track Order</h1>
          {this.state.error && <div className="bg-red-400 p-2 rounded text-gray-700 flex items-center space-"> <i className=" text-red-400  text-lg im im-info"></i> <p>
            Tracking number not found, enter a valid tracking number</p></div>}
          <form onSubmit={this.onSubmit}>
            <div className="flex flex-col space-y-1">
              <label htmlFor="username" className="text-sm font-bold text-gray-500">Tracking Code</label>
              <div className="relative">
                <input type="text"
                  value={this.state.trackOrderNumber}
                  onChange={event => this.setState({ trackOrderNumber: event.target.value })}
                  className="block appearance-none tracking-wide w-full bg-gray-100 border border-gray-100 text-gray-500 py-3 px-4 pr-8 rounded" placeholder="Enter tracking code" required />
              </div>
            </div>
            <div className="text-center mt-5">
              <button
                type="submit"
                disabled={this.state.isLoading}
                className="inline-block bg-green-700 text-green-100 font-medium uppercase py-3 shadow px-16 rounded-md">{this.state.isLoading ? "Tracking..." : "Start Tracking"}</button>
            </div>
          </form>
        </div>
        }
      </div>
    )
  }
}


function App() {

  return (
    <div>
      <TrackOrder />
    </div>
  );
}

ReactDOM.render(
  <App />,
  document.getElementById('third')
);